####################
# Copyright (c) 2009, Benjamin Schollnick. All rights reserved.
# http://www.schollnick.net
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
#
# IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
# INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
####################

####################
## IMPORTS
## IMPORTS
import cherrypy
from cherrypy import _cperror

from indigopy import indigoconn as ic
from indigopy import indigodb as idb
from indigopy.basereqhandler import BaseRequestHandler, kTrueStr, kFalseStr, kEmptyStr, kTextPageStr, kHtmlPageStr, kXmlPageStr

import socket
import os
import os.path
import sys
import csv
import cgi

####################
## CONSTANTS

####################
# Optional hooks to provide a plugin name and description (shown in Event Log and plugin index)
def PluginName():
	return u"Device that are On!"

def PluginDescription():
	return u"Displays that are On!"

def ShowOnControlPageList():
	return True		# if True, then above name/description is shown on the Control Page list index

# Optional hook called when the IndigoWebServer first connects to IndigoServer
def IndigoConnected():
	pass

# Optional hook called when the IndigoWebServer disconnect from IndigoServer
def IndigoDisconnected():
	pass

####################

####################
# The functions in this class are automatically called based on the URL
# requested. This provides a mechanism for easily serving dynamic content.
#
# The URL path is based on the folder path of the plugin. For example,
# this plugin folder name is "sample" so any URL path containing "sample"
# as the first path identifier will call into these functions.
#
# The class name can be called whatever you want, but it must subclass
# from BaseRequestHandler to be loaded by the webserver plugin manager.
class HaloHomeRequestHandler(BaseRequestHandler):

        def __init__(self, logFunc, debugLogFunc):
                BaseRequestHandler.__init__(self, logFunc, debugLogFunc)

        ####################
        def index(self):  
                self._Log ("Displaying Remote Device Display Listings")
                cherrypy.response.headers['Content-Type'] = 'text/html'
                html_elems = []
                html_elems.append("<html>\n")
                html_elems.append ("<head>\n")
                html_elems.append("<title>Devices that are On!</title></Head>\n")
                html_elems.append("<body>\n")

                dev_list = cherrypy.server.indigoDb.GetDevices(cherrypy.server.indigoConn, True)
                html_elems.append ("<table border=1>")
                html_elems.append ("<TR>")
                html_elems.append ("<TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD>" % ( "Device Name", "Description", "Addr", "Device Type", "Status", "Last Updated") )
                html_elems.append ("</TR>\n")
                for x in dev_list:
                        if x.displayRawState not in ["off", "0"]:
                                html_elems.append ("<TR>\n")
                                if x.versByte <> 0:
                                        hex_value = str(hex(x.versByte))[2:4]
                                else:
                                        hex_value = "00"

                                if len(hex_value) < 2:
                                        hex_value = "0" + hex_value

                                x.name = '<a href="/devices/%s?isOn=0&_method=put">%s</a>' % (x.name.replace(" ", "%20"), x.name)
                                #x.name = '<a href="#" onclick="restUpdateRequest("/devices/%s", "isOn=1"); return false;"> %s </a>' % (x.name.replace(" ", "%20"), x.name)
                                
                                html_elems.append ("<TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD><TD>%s</TD>" % (x.name, x.desc, x.addressStr,
                                                                                                                                     x.type, 
                                                                                                                                     x.displayRawState, x.lastChangedDateStr ) )
                                html_elems.append ("</TR>\n")
                html_elems.append ("</table>")
                        
                html_elems.append("</body>\n")
                return ''.join(html_elems)

        index.exposed = True

##['__cmp__', '__doc__', '__init__', '__module__', 'activeZone', 'address', 'addressStr', 'brightness', 'desc',
## 'deviceState', 'displayInUI', 'hasStateToDisplay', 'hvacCurrentMode', 'hvacFanMode', 'inputAnalogStates',
## 'inputBinaryStates', 'inputHumidityVals', 'inputSensorStates', 'inputTemperatureVals', 'isOn', 'lastChanged',
## 'lastChangedRFC3339', 'lastChangedRFC822', 'lastChangedStr', 'name', 'outputBinaryStates', 'outputTimers', 'setpointCool',
## 'setpointHeat', 'type', 'typeFlags', 'typeSupportsDim', 'typeSupportsHVAC', 'typeSupportsIO',
## 'typeSupportsOnOff', 'typeSupportsSprinkler', 'zoneNames'] 
